# youtube-search-python


**Search videos in YouTube without using YouTube Data API v3.**


(Made from scratch without using YouTube Data API v3 and any other third party library!)


Working as of 2020.


## Install


```pip3 install youtube-search-python```


## Usage


```python

from youtubesearchpython import searchYoutube

search = searchYoutube("NoCopyrightSounds", 1, "json")

print(search.result());

```


## Like the module?


Consider starring the repo. Feel free to use.


